==> netrw-0.99.1.tar.bz2: netrw-0.99.1/src/progress.c <==
/* $Id: progress.c,v 1.2 2002/10/13 13:05:12 jirka Exp $ */

/*
 * netrw tools
 * Copyright (C) 2002 Jiri Denemark
 *
 * This file is part of netrw.
 *
 * netrw is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#if HAVE_CONFIG_H
#include "config.h"
#endif

#if STDC_HEADERS
#include <stdio.h>
#endif
#if HAVE_UNISTD_H
#include <unistd.h>
#endif
#include <time.h>

#if HAVE_UNSIGNED_LONG_LONG
#define UNSIGNED_LONG_LONG unsigned long long
#else
#define UNSIGNED_LONG_LONG unsigned long
#endif

#include "common.h"
#include "progress.h"


static int after = DEFAULT_HASH_AFTER * KILO;
static UNSIGNED_LONG_LONG hashes = 0;
static UNSIGNED_LONG_LONG bytes = 0;
static time_t start;


/* static functions */
static void print_bytes(unsigned long long bytes);


void progress_hash_after(int kbytes)
{
    after = (kbytes <= 0 ? DEFAULT_HASH_AFTER : kbytes) * KILO;
}

void progress_data(unsigned long transferred_bytes)
{
    if (!can_print(NORMAL))
        return;

    if (bytes == 0)
        start = time(NULL);

    bytes += transferred_bytes;
    while ((bytes / after) >= (hashes + 1)) {
        hashes++;
        write(STDERR_FILENO, "#", 1);
        if (hashes % 50 == 0) {
            write(STDERR_FILENO, " ", 1);
            print_bytes(hashes * after);
            write(STDERR_FILENO, "\n", 1);
        }
        else if (hashes % 10 == 0)
            write(STDERR_FILENO, " ", 1);
    }

    fflush(stderr);
}

void progress_summary(void)
{
    double speed;
    double diff;

    if (!can_print(NORMAL))
        return;

    if (bytes == 0) {
        print(NORMAL, "\nno data transferred\n");
        return;
    }

    print(NORMAL, "\n");
    print_bytes(bytes);
    print(NORMAL, " transferred at ");

    diff = difftime(time(NULL), start);
    speed = (diff == 0 ? 0 : bytes / diff);
    if (speed > GIGA)
        print(NORMAL, "%0.2f GB/s", speed / (1.0 * GIGA));
    else if (speed > MEGA)
        print(NORMAL, "%0.2f MB/s", speed / (1.0 * MEGA));
    else if (speed > KILO)
        print(NORMAL, "%0.2f KB/s", speed / (1.0 * KILO));
    else
        print(NORMAL, "%0.2f B/s", speed);
    print(NORMAL, " (%d seconds)\n", (int) diff);
}


static void print_bytes(unsigned long long bytes)
{
    if (bytes >= GIGA)
        print(NORMAL, " %7.2f GBytes", bytes / (1.0 * GIGA));
    else if (bytes >= MEGA)
        print(NORMAL, " %7.2f MBytes", bytes / (1.0 * MEGA));
    else if (bytes >= KILO)
        print(NORMAL, " %7.2f KBytes", bytes / (1.0 * KILO));
    else
        print(NORMAL, " %7d Bytes", (int) bytes);
}

==> netrw-1.0.1.tar.bz2: netrw-1.0.1/src/progress.c <==
/* $Id: progress.c,v 1.3 2002/11/08 22:40:56 jirka Exp $ */

/*
 * netrw tools
 * Copyright (C) 2002 Jiri Denemark
 *
 * This file is part of netrw.
 *
 * netrw is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#if HAVE_CONFIG_H
#include "config.h"
#endif

#if STDC_HEADERS
#include <stdio.h>
#endif
#if HAVE_UNISTD_H
#include <unistd.h>
#endif
#include <time.h>

#if HAVE_UNSIGNED_LONG_LONG
#define UNSIGNED_LONG_LONG unsigned long long
#else
#define UNSIGNED_LONG_LONG unsigned long
#endif

#include "common.h"
#include "progress.h"


static int after = DEFAULT_HASH_AFTER * KILO;
static UNSIGNED_LONG_LONG hashes = 0;
static UNSIGNED_LONG_LONG bytes = 0;
static time_t start;


/* static functions */
static void print_bytes(unsigned long long bytes);


void progress_hash_after(int kbytes)
{
    after = (kbytes <= 0 ? DEFAULT_HASH_AFTER : kbytes) * KILO;
}

void progress_data(unsigned long transferred_bytes)
{
    if (!can_print(NORMAL))
        return;

    if (bytes == 0)
        start = time(NULL);

    bytes += transferred_bytes;
    while ((bytes / after) >= (hashes + 1)) {
        hashes++;
        write(STDERR_FILENO, "#", 1);
        if (hashes % 50 == 0) {
            write(STDERR_FILENO, " ", 1);
            print_bytes(hashes * after);
            write(STDERR_FILENO, "\n", 1);
        }
        else if (hashes % 10 == 0)
            write(STDERR_FILENO, " ", 1);
    }

    fflush(stderr);
}

void progress_summary(void)
{
    double speed;
    double diff;

    if (!can_print(NORMAL))
        return;

    if (bytes == 0) {
        print(NORMAL, "\nno data transferred\n");
        return;
    }

    print(NORMAL, "\n");
    print_bytes(bytes);
    print(NORMAL, " transferred at ");

    diff = difftime(time(NULL), start);
    speed = (diff == 0 ? 0 : bytes / diff);
    if (speed > GIGA)
        print(NORMAL, "%0.2f GB/s", speed / (1.0 * GIGA));
    else if (speed > MEGA)
        print(NORMAL, "%0.2f MB/s", speed / (1.0 * MEGA));
    else if (speed > KILO)
        print(NORMAL, "%0.2f KB/s", speed / (1.0 * KILO));
    else
        print(NORMAL, "%0.2f B/s", speed);
    print(NORMAL, " (%d seconds)\n", (int) diff);
}


static void print_bytes(unsigned long long bytes)
{
    if (bytes >= GIGA)
        print(NORMAL, " %7.2f GB", bytes / (1.0 * GIGA));
    else if (bytes >= MEGA)
        print(NORMAL, " %7.2f MB", bytes / (1.0 * MEGA));
    else if (bytes >= KILO)
        print(NORMAL, " %7.2f KB", bytes / (1.0 * KILO));
    else
        print(NORMAL, " %7d B", (int) bytes);
}
